Module lexer

Module lexer 

Logos-based lexer that tokenises .bub source and expression strings.

Enums

Token
A lexical token produced by the lexer.

Functions

tokenise
Lexes input into a Vec of spanned tokens, returning an error on any character that does not match a known token.

Type Aliases

Spanned
A spanned token pair.