VariableDecl

Struct VariableDecl 

pub struct VariableDecl {
    pub name: String,
    pub default_src: String,
}
A <<declare $var = expr>> entry collected from a compiled program.

These declarations are useful for save systems that need to know the full set of variables a script uses and their default expressions.

Fields

name: String

Variable name including the $ sigil.

default_src: String

The default-value expression source, as written in the script.