#[non_exhaustive]pub enum DialogueError {
Parse {
file: String,
line: usize,
message: String,
},
UnknownNode(String),
DuplicateNode(String),
Validation(String),
Runtime(String),
Type(String),
UndefinedVariable(String),
Function {
name: String,
message: String,
},
}Expand description
All errors that can be produced by compilation or runtime execution.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Parse
A parse-time error, optionally localised to a source span.
Fields
UnknownNode(String)
A reference to an unknown node.
DuplicateNode(String)
A duplicate node title was found across merged sources.
Validation(String)
A validation failure detected after all sources are merged.
Runtime(String)
A runtime execution error.
Type(String)
A type mismatch in an expression.
UndefinedVariable(String)
An unknown variable was referenced.
Function
A function call failed.